@@ -2,13 +2,17 @@ package Parallel::Tiny;
 use strict;
 use warnings;
 use POSIX qw(WNOHANG);
+use Sys::Prctl qw(prctl);
+
+use constant PR_SET_PDEATHSIG => 1;
+use constant SIGHUP           => 1;
 
 use constant DEFAULT_ERROR_TIMEOUT => 10;
 use constant DEFAULT_WORKERS       => 1;
 use constant DEFAULT_REAP_TIMEOUT  => .1;
 use constant DEFAULT_WORKER_TOTAL  => 1;
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 =head1 NAME
 
@@ -119,6 +123,8 @@ sub run {
         }
 
         # child work
+        prctl(PR_SET_PDEATHSIG, SIGHUP);
+        $SIG{$_} = 'DEFAULT' for keys(%SIG);
         $0 = $0 . ' - worker';
         $handler->run();
 
